@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 package Apache::SWIT::Test::Request;
 use base 'Class::Accessor';
 
-__PACKAGE__->mk_accessors(qw(_param));
+__PACKAGE__->mk_accessors(qw(_param _pnotes));
 
 sub server_root_relative {
 	return $_[1];
@@ -31,4 +31,11 @@ sub parse_url {
 	$self->_param(\%res);
 }
 
+sub pnotes {
+	my ($self, $name, $val) = @_;
+	$self->_pnotes({}) unless $self->_pnotes;
+	return $self->_pnotes->{$name} unless scalar(@_) > 2;
+	$self->_pnotes->{$name} = $val;
+}
+
 1;
